@@ -17,7 +17,6 @@
 from taskflow.engines.action_engine import engine
 from taskflow.engines.worker_based import executor
 from taskflow.engines.worker_based import protocol as pr
-from taskflow import storage as t_storage
 
 
 class WorkerBasedActionEngine(engine.ActionEngine):
@@ -37,8 +36,9 @@ class WorkerBasedActionEngine(engine.ActionEngine):
                                of the (PENDING, WAITING) request states. When
                                expired the associated task the request was made
                                for will have its result become a
-                               `RequestTimeout` exception instead of its
-                               normally returned value (or raised exception).
+                               :py:class:`~taskflow.exceptions.RequestTimeout`
+                               exception instead of its normally returned
+                               value (or raised exception).
     :param transport_options: transport specific options (see:
                               http://kombu.readthedocs.org/ for what these
                               options imply and are expected to be)
@@ -46,8 +46,6 @@ class WorkerBasedActionEngine(engine.ActionEngine):
                           (see: :py:attr:`~.proxy.Proxy.DEFAULT_RETRY_OPTIONS`)
     """
 
-    _storage_factory = t_storage.SingleThreadedStorage
-
     def __init__(self, flow, flow_detail, backend, options):
         super(WorkerBasedActionEngine, self).__init__(flow, flow_detail,
                                                       backend, options)
